caellion-python-commons: tests.test_hashing_file_hashing.TestHashingFileHasher Class Reference

caellion-python-commons

Public Member Functions | Static Public Attributes | List of all members
tests.test_hashing_file_hashing.TestHashingFileHasher Class Reference

## Public Member Functions
def | test_unsupported_algorithm (self)
def | test_get_hexdigest_not_done_hash_bytes (self)
def | test_get_hexdigest_not_done_hash_hex (self)
def | test_cannot_hash_twice_raw (self)
def | test_cannot_hash_twice_path (self)
def | test_hashes_file_ok_raw (self, path, algo, expected)
def | test_hashes_file_ok_hexdigest (self, path, algo, expected)
def | test_hashes_path_ok_raw (self, path, algo, expected)
def | test_hashes_path_ok_hexdigest (self, path, algo, expected)
def | test_hashes_file_ok_raw_combo (self, path, algo, expected)
def | test_hashes_file_ok_hexdigest_combo (self, path, algo, expected)
def | test_hashes_path_ok_raw_combo (self, path, algo, expected)
def | test_hashes_path_ok_hexdigest_combo (self, path, algo, expected)

## Static Public Attributes
| maxDiff = None

## Detailed Description

Definition at line 42 of file test_hashing_file_hashing.py.

## Member Function Documentation

## ◆ test_cannot_hash_twice_path()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_cannot_hash_twice_path | ( |  | self | ) |

Definition at line 68 of file test_hashing_file_hashing.py.

## ◆ test_cannot_hash_twice_raw()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_cannot_hash_twice_raw | ( |  | self | ) |

Definition at line 61 of file test_hashing_file_hashing.py.

## ◆ test_get_hexdigest_not_done_hash_bytes()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_get_hexdigest_not_done_hash_bytes | ( |  | self | ) |

Definition at line 51 of file test_hashing_file_hashing.py.

## ◆ test_get_hexdigest_not_done_hash_hex()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_get_hexdigest_not_done_hash_hex | ( |  | self | ) |

Definition at line 56 of file test_hashing_file_hashing.py.

## ◆ test_hashes_file_ok_hexdigest()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_file_ok_hexdigest | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 83 of file test_hashing_file_hashing.py.

## ◆ test_hashes_file_ok_hexdigest_combo()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_file_ok_hexdigest_combo | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 112 of file test_hashing_file_hashing.py.

## ◆ test_hashes_file_ok_raw()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_file_ok_raw | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 75 of file test_hashing_file_hashing.py.

## ◆ test_hashes_file_ok_raw_combo()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_file_ok_raw_combo | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 105 of file test_hashing_file_hashing.py.

## ◆ test_hashes_path_ok_hexdigest()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_path_ok_hexdigest | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 98 of file test_hashing_file_hashing.py.

## ◆ test_hashes_path_ok_hexdigest_combo()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_path_ok_hexdigest_combo | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 125 of file test_hashing_file_hashing.py.

## ◆ test_hashes_path_ok_raw()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_path_ok_raw | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 91 of file test_hashing_file_hashing.py.

## ◆ test_hashes_path_ok_raw_combo()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_hashes_path_ok_raw_combo | ( |  | self,
|  |  | path,
|  |  | algo,
|  |  | expected
| ) |  |

Definition at line 119 of file test_hashing_file_hashing.py.

## ◆ test_unsupported_algorithm()

def tests.test_hashing_file_hashing.TestHashingFileHasher.test_unsupported_algorithm | ( |  | self | ) |

Definition at line 47 of file test_hashing_file_hashing.py.

## Member Data Documentation

## ◆ maxDiff

tests.test_hashing_file_hashing.TestHashingFileHasher.maxDiff = None
| static

Definition at line 44 of file test_hashing_file_hashing.py.

The documentation for this class was generated from the following file:

- tests/test_hashing_file_hashing.py